@@ -46,12 +46,13 @@ SURVEY_VERSION = '1'
 
 def _search_file(x, dir='path.share'):
 	tests = [
-		lambda x: os.path.join(os.path.join(os.getcwd(),x)),
-		lambda x: os.path.join(os.path.join(options.options[dir],x)),
+		lambda x: os.path.join(options.options[dir],x),
+		lambda x: os.path.join(os.getcwd(),x),
 	]
-	while not os.path.isfile(x):
-		assert len(tests), 'Could not find path for %s !\nTry to edit ~/.terprc or run Tiny ERP from it\'s install path.' % x
-		x = tests.pop()(x)
+	for func in tests:
+		if os.path.exists(x):
+			break
+		x = func(x)
 	return x
 
 terp_path = _search_file
@@ -244,10 +245,10 @@ def test():
 	widget.destroy()
 	return True
 
-def file_selection(title, ext='csv', filename='.'):
+def file_selection(title, filename=''):
 	win = gtk.FileSelection(title)
-	win.set_filename(os.path.join(options.options['client.default_path'], filename))
-
+	if filename:
+		win.set_filename(os.path.join(options.options['client.default_path'], filename))
 	win.set_select_multiple(False)
 	
 	button = win.run()
@@ -359,8 +360,6 @@ def error(title, message, details=''):
 	sur.signal_connect('on_closebutton_clicked', lambda x : win.destroy())
 
 	response = win.run()
-#	if response == gtk.RESPONSE_OK:
-#		print 'ok'
 	win.destroy()
 	return True
 
@@ -376,6 +375,21 @@ def message(msg, type=gtk.MESSAGE_INFO):
 def to_xml(s):
 	return s.replace('&','&amp;').replace('<','&lt;').replace('>','&gt;')
 
+def message_box(title, msg, parent=None):
+	dia = glade.XML(terp_path("terp.glade"), "dia_message_box",gettext.textdomain())
+	win = dia.get_widget('dia_message_box')
+	l = dia.get_widget('msg_title')
+	l.set_text(title)
+
+	buffer = dia.get_widget('msg_tv').get_buffer()
+	iter_start = buffer.get_start_iter()
+	buffer.insert(iter_start, msg)
+
+	response = win.run()
+	win.destroy()
+	return True
+
+
 def warning(msg, title='', parent=None):
 	dialog = gtk.MessageDialog(parent, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_WARNING, gtk.BUTTONS_OK)
 	dialog.set_markup('<b>%s</b>\n\n%s' % (to_xml(title),to_xml(msg)))
@@ -402,5 +416,28 @@ def sur_3b(msg):
 	win.destroy()
 	return {gtk.RESPONSE_NO : 'ko', gtk.RESPONSE_CANCEL : 'cancel', gtk.RESPONSE_YES : 'ok'}[response]
 
+def theme_set():
+	theme = options['client.theme']
+	if theme and (theme <> 'none'):
+		fname = os.path.join("themes", theme, "gtkrc")
+		if not os.path.isfile(fname):
+			common.warning('File not found: '+fname+'\nSet theme to none in ~/.terprc', 'Error setting theme')
+			return False
+		gtk.rc_parse("themes/"+theme+"/gtkrc")
+	return True
+
+def ask(question):
+	dia = glade.XML(terp_path('terp.glade'), 'win_quest', gettext.textdomain())
+	win = dia.get_widget('win_quest')
+	label = dia.get_widget('label')
+	label.set_text(question)
+	entry = dia.get_widget('entry')
+	response = win.run()
+	win.destroy()
+	if response == gtk.RESPONSE_CANCEL:
+		return None
+	else:
+		return entry.get_text()
+
 def dec_trunc(nbr, prec=2):
 	return round(nbr * (10 ** prec)) / 10**prec
