@@ -52,11 +52,11 @@ class main(service.Service):
 				return False
 			datas['id'] = ids[0]
 		try:
-			res = rpc.session.rpc_exec_auth('/report', 'report', name, ids, datas, rpc.session.context)
+			report_id = rpc.session.rpc_exec_auth('/report', 'report', name, ids, datas, rpc.session.context)
 			state = False
 			attempt = 0
 			while not state:
-				val = rpc.session.rpc_exec_auth('/report', 'report_get', res)
+				val = rpc.session.rpc_exec_auth('/report', 'report_get', report_id)
 				state = val['state']
 				if not state:
 					time.sleep(1)
@@ -111,7 +111,7 @@ class main(service.Service):
 		elif action['type']=='ir.actions.report.xml':
 			self.exec_report(action['report_name'], datas)
 
-	def exec_keyword(self, keyword, data={}):
+	def exec_keyword(self, keyword, data={}, adds={}):
 		actions = None
 		if 'id' in data:
 			try:
@@ -124,6 +124,7 @@ class main(service.Service):
 		keyact = {}
 		for action in actions:
 			keyact[action['name']] = action
+		keyact.update(adds)
 
 		res = common.selection(_('Select your action'), keyact)
 		if res:
