@@ -3,7 +3,7 @@
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #					Fabien Pinckaers <fp@tiny.Be>
 #
-# $Id: main.py 3092 2006-05-04 13:22:43Z nicoe $
+# $Id: main.py 4044 2006-09-05 14:06:27Z ged $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -28,12 +28,15 @@
 #
 ##############################################################################
 
+import time
+import os
+import gettext
+import urlparse
+
+import gobject
 import gtk
 from gtk import glade
-import gettext
-import time
 
-import string
 import rpc
 
 import service
@@ -51,10 +54,12 @@ def _login_ask():
 	passwd = win_gl.get_widget('ent_passwd')
 	host = win_gl.get_widget('ent_host')
 	port = win_gl.get_widget('ent_port')
+	secure = win_gl.get_widget('ent_secure')
 
 	port.set_text(options.options['login.port'])
 	host.set_text(options.options['login.server'])
 	login.set_text(options.options['login.login'])
+	secure.set_active(options.options['login.secure'])
 	
 	# deselect the text in the host/server field since
 	# the focus is on the password field
@@ -64,7 +69,7 @@ def _login_ask():
 	if res == gtk.RESPONSE_CANCEL:
 		win.destroy()
 		raise 'QueryCanceled'
-	result = (login.get_text(), passwd.get_text(), host.get_text(), port.get_text())
+	result = (login.get_text(), passwd.get_text(), host.get_text(), port.get_text(), secure.get_active())
 	win.destroy()
 	return result
 	
@@ -75,11 +80,14 @@ class terp_main(service.Service):
 
 		self.glade = glade.XML(common.terp_path("terp.glade"),"win_main",gettext.textdomain())
 		self.status_bar_main = self.glade.get_widget('hbox_status_main')
-		self.status_bar = self.glade.get_widget('sb_main')
 		self.toolbar = self.glade.get_widget('main_toolbar')
 		self.sb_requests = self.glade.get_widget('sb_requests')
 		self.sb_username = self.glade.get_widget('sb_user_name')
 		self.sb_servername = self.glade.get_widget('sb_user_server')
+		id = self.sb_servername.get_context_id('message')
+		self.sb_servername.push(id, _('Press Ctrl+O to login'))
+		self.secure_img = self.glade.get_widget('secure_img')
+		self.secure_img.hide()
 
 		window = self.glade.get_widget('win_main')
 		window.connect("destroy", self.sig_quit)
@@ -92,7 +100,38 @@ class terp_main(service.Service):
 		self.sig_id = self.notebook.connect_after('switch-page', self._sig_page_changt)
 		vbox = self.glade.get_widget('vbox_main')
 		vbox.pack_start(self.notebook, expand=True, fill=True)
-		
+
+		#
+		# Code to add themes to the options->theme menu
+		#
+		submenu = gtk.Menu()
+		menu = self.glade.get_widget('menu_theme')
+		old = None
+		for dname in os.listdir(common.terp_path('themes')):
+			if dname.startswith('.'):
+				continue
+			fname = common.terp_path(os.path.join('themes', dname, 'gtkrc'))
+			if os.path.isfile(fname):
+				open_item = gtk.RadioMenuItem(old, dname)
+				old = open_item
+				submenu.append(open_item)
+				if dname == options.options['client.theme']:
+					open_item.set_active(True)
+				open_item.connect('toggled', self.theme_select, dname)
+
+		submenu.append(gtk.SeparatorMenuItem())
+		open_item = gtk.RadioMenuItem(old, _('Default Theme'))
+		submenu.append(open_item)
+		if 'none'==options.options['client.theme']:
+			open_item.set_active(True)
+		open_item.connect('toggled', self.theme_select, 'none')
+		submenu.show_all()
+		menu.set_submenu(submenu)
+
+		#
+		# Default Notebook
+		#
+
 		self.notebook.show()
 		self.pages = []
 		self.current_page = 0
@@ -112,7 +151,7 @@ class terp_main(service.Service):
 			'on_read_requests_activate': self.sig_request_open,
 			'on_send_request_activate': self.sig_request_new,
 			'on_request_wait_activate': self.sig_request_wait,
-			'on_opt_save_activate': lambda x: options.options.save() and self.message(_('Options saved!')),
+			'on_opt_save_activate': lambda x: options.options.save(),
 			'on_menubar_icons_activate': lambda x: self.sig_menubar('icons'),
 			'on_menubar_text_activate': lambda x: self.sig_menubar('text'),
 			'on_menubar_both_activate': lambda x: self.sig_menubar('both'),
@@ -123,18 +162,18 @@ class terp_main(service.Service):
 			'on_help_tips_activate': self.sig_tips,
 			'on_help_licence_activate': self.sig_licence,
 			'on_about_activate': self.sig_about,
+			'on_shortcuts_activate' : self.sig_shortcuts,
 		}
 		for signal in dict:
 			self.glade.signal_connect(signal, dict[signal])
 
 		self.buttons = {}
-		for button in ('but_new', 'but_save', 'but_remove', 'but_search', 'but_previous', 'but_next', 'but_action', 'but_open', 'but_print', 'but_close', 'but_reload', 'but_switch','but_attach', 'but_preference'):
+		for button in ('but_new', 'but_save', 'but_remove', 'but_search', 'but_previous', 'but_next', 'but_action', 'but_open', 'but_print', 'but_close', 'but_reload', 'but_switch','but_attach'):
 			self.glade.signal_connect('on_'+button+'_clicked', self._sig_child_call, button)
 			self.buttons[button]=self.glade.get_widget(button)
 
 		menus = {
 			'form_del': 'but_remove',
-			'form_preference': 'but_preference',
 			'form_new': 'but_new',
 			'form_copy': 'but_copy',
 			'form_reload': 'but_reload',
@@ -158,7 +197,6 @@ class terp_main(service.Service):
 		spool = service.LocalService('spool')
 		spool.subscribe('gui.window', self.win_add)
 
-		self.message(_('Welcome to Tiny Enterprise Resource Planing !'))
 		self.sb_set()
 
 		def fnc_menuitem(menuitem, opt_name):
@@ -172,6 +210,15 @@ class terp_main(service.Service):
 			self.glade.signal_connect(signal, dict[signal][0], dict[signal][1])
 			self.glade.get_widget(dict[signal][2]).set_active(int(bool(options.options[dict[signal][1]])))
 
+		# Adding a timer the check to requests
+		gobject.timeout_add(5 * 60 * 1000, self.request_set)
+
+	def theme_select(self, widget, theme):
+		options.options['client.theme'] = theme
+		common.theme_set()
+		self.window.show_all()
+		return True
+
 	def sig_mode_change(self, pda_mode=False):
 		options.options['client.modepda'] = pda_mode
 		return self.sig_mode()
@@ -232,34 +279,40 @@ class terp_main(service.Service):
 		obj.create(False, 'res.request', ids, [('act_from','=',rpc.session.uid), ('state','=','waiting')], 'form', mode='tree,form')
 
 	def request_set(self):
-		uid = rpc.session.uid
-		ids,ids2 = rpc.session.rpc_exec_auth('/object', 'execute', 'res.request', 'request_get')
-		if len(ids):
-			message = str(len(ids))+_(' request(s)')
-		else:
-			message = _('No request')
-		if len(ids2):
-			message += ' - '+str(len(ids2))+_(' pending request(s)')
-		id = self.sb_requests.get_context_id('message')
-		self.sb_requests.push(id, message)
-		return (ids,ids2)
+		try:
+			uid = rpc.session.uid
+			ids,ids2 = rpc.session.rpc_exec_auth_wo('/object', 'execute', 'res.request', 'request_get')
+			if len(ids):
+				message = _('%s request(s)') % len(ids)
+			else:
+				message = _('No request')
+			if len(ids2):
+				message += _(' - %s pending request(s)') % len(ids2)
+			id = self.sb_requests.get_context_id('message')
+			self.sb_requests.push(id, message)
+			return (ids,ids2)
+		except:
+			return ([],[])
 
 	def sig_login(self, widget=None):
 		if rpc.session.logged():
-			self.message(_('You are already logged!'))
+			pass
 		else:
 			try:
 				try:
 					res = _login_ask()
 				except 'QueryCanceled':
 					return False
-				log_response = rpc.session.login(res[0], res[1], res[2], res[3])
+				log_response = rpc.session.login(*res)
 				if log_response==1:
 					options.options['login.server'] = res[2]
 					options.options['login.login'] = res[0]
 					options.options['login.port'] = res[3]
+					options.options['login.secure'] = res[4]
 					options.options.save()
 					self.sig_win_new()
+					if res[4]:
+						self.secure_img.show()
 					self.request_set()
 				elif log_response==-1:
 					common.message(_('Connection error !\nUnable to connect to the server !'))
@@ -278,6 +331,9 @@ class terp_main(service.Service):
 		self.sb_requests.push(id, '')
 		id = self.sb_username.get_context_id('message')
 		self.sb_username.push(id, _('Not logged !'))
+		id = self.sb_servername.get_context_id('message')
+		self.sb_servername.push(id, _('Press Ctrl+O to login'))
+		self.secure_img.hide()
 		rpc.session.logout()
 		
 	def sig_help_index(self, widget):
@@ -291,8 +347,8 @@ class terp_main(service.Service):
 		common.tipoftheday()
 		
 	def sig_licence(self, widget):
-		about = glade.XML(common.terp_path("terp.glade"), "win_licence", gettext.textdomain())
-		about.signal_connect("on_but_ok_pressed", lambda obj: about.get_widget('win_licence').destroy())
+		dialog = glade.XML(common.terp_path("terp.glade"), "win_licence", gettext.textdomain())
+		dialog.signal_connect("on_but_ok_pressed", lambda obj: dialog.get_widget('win_licence').destroy())
 
 	def sig_about(self, widget):
 		about = glade.XML(common.terp_path("terp.glade"), "win_about", gettext.textdomain())
@@ -301,12 +357,20 @@ class terp_main(service.Service):
 		buffer.set_text(about_txt % tinyerp_version)
 		about.signal_connect("on_but_ok_pressed", lambda obj: about.get_widget('win_about').destroy())
 
+	def sig_shortcuts(self, widget):
+		shortcuts_win = glade.XML(common.terp_path('terp.glade'), 'shortcuts_dia', gettext.textdomain())
+		shortcuts_win.signal_connect("on_but_ok_pressed", lambda obj: shortcuts_win.get_widget('shortcuts_dia').destroy())
+
 	def sig_win_new(self, widget=None):
 		act_id = rpc.session.rpc_exec_auth('/object', 'execute', 'res.users', 'read', [rpc.session.uid], ['action_id','name'], rpc.session.context)
 		id = self.sb_username.get_context_id('message')
 		self.sb_username.push(id, act_id[0]['name'] or '')
 		id = self.sb_servername.get_context_id('message')
-		self.sb_servername.push(id, rpc.session._url)
+		self.sb_servername.push(id, urlparse.urlsplit(rpc.session._url)[1])
+		if not act_id[0]['action_id']:
+			common.warning('You can not log into the system !\nAsk the administrator to verify\nyou have an action defined for your user.','Access Denied !')
+			rpc.session.logout()
+			return False
 		act_id = act_id[0]['action_id'][0]
 		obj = service.LocalService('action.main')
 		win = obj.execute(act_id, {'window':self.window}, 'ir.actions.act_window')
@@ -321,7 +385,6 @@ class terp_main(service.Service):
 		while self._win_del():
 			pass
 		rpc.session.logout()
-		self.message(_('You are logged out. Press Ctrl+O to login'))
 
 	def sig_quit(self, widget):
 		gtk.main_quit()
@@ -345,10 +408,6 @@ class terp_main(service.Service):
 	def sb_set(self, view=None):
 		if view==None:
 			view = self._wid_get()
-		if view:
-			self.message(_('^N New   ^S Save   ^D Delete   ^F Find   ^X Next   ^Z Previous   ^R Repeat'))
-		else:
-			self.message(_('Press Ctrl+O to login'))
 		for x in self.buttons:
 			if self.buttons[x]:
 				self.buttons[x].set_sensitive(view and (x in view.handlers))
