@@ -54,6 +54,10 @@ class tree(object):
 		ids = rpc.session.rpc_exec_auth('/object', 'execute', self.model, 'search', self.domain2)
 		self.tree_res = view_tree.view_tree(view, ids, res_id, True, context=context)
 		self.tree_res.view.connect('row-activated', self.sig_open)
+		#self.tree_res.view.connect('row-activated', self.sig_open)
+		sel = self.tree_res.view.get_selection()
+		sel.connect('changed', self.expand_one)
+
 		self.name = self.tree_res.name
 		vp.add(self.tree_res.widget_get())
 		
@@ -64,6 +68,10 @@ class tree(object):
 			wid.show()
 
 		widget_sc = self.glade.get_widget('win_tree_sc')
+
+		imagename = 'tinyerp.png'
+
+		
 		widget_sc.connect('row-activated', self.sc_go)
 		self.tree_sc = view_tree.view_tree_sc(widget_sc, self.model)
 		self.handlers = {
@@ -84,6 +92,10 @@ class tree(object):
 		for signal in dict:
 			self.glade.signal_connect(signal, dict[signal])
 
+	def expand_one(self, selection):
+		model,iter = selection.get_selected_rows()
+		self.tree_res.view.expand_row(iter[0], False)
+
 	def sig_print_html(self, widget=None, keyword='client_print_multi', id=None):
 		self.sig_action(keyword='client_print_multi', report_type='html')
 
