@@ -31,6 +31,7 @@ import gobject
 from xml.parsers import expat
 
 import options
+import time
 
 import rpc
 import gettext
@@ -38,6 +39,9 @@ import parse
 
 import copy
 
+DT_FORMAT = '%Y-%m-%d'
+DHM_FORMAT = '%Y-%m-%d %H:%M:%S'
+
 # BUG: ids = []
 #
 # Tree struct:  [ id, values, childs, childs_id ]
@@ -79,6 +83,16 @@ class view_tree_model(gtk.GenericTreeModel, gtk.TreeSortable):
 						val[f]=''
 				res_ids.append(val)
 		for field in self.fields:
+			if self.fields_type[field]['type'] in ('date',):
+				for x in res_ids:
+					if x[field]:
+						date = time.strptime(x[field], DT_FORMAT)
+						x[field] = time.strftime('%x', date)
+			if self.fields_type[field]['type'] in ('datetime',):
+				for x in res_ids:
+					if x[field]:
+						date = time.strptime(x[field], DHM_FORMAT)
+						x[field] = time.strftime('%x %H:%M:%S', date)
 			if self.fields_type[field]['type'] in ('one2one','many2one'):
 				for x in res_ids:
 					if x[field]:
