@@ -47,9 +47,10 @@ class win_attach(object):
 		self.win = self.glade.get_widget('win_attach')
 		self.ressource = (model, id)
 
-		hb = self.glade.get_widget('attach_hbox')
 		self.view = gtk.TreeView()
-		hb.pack_start(self.view)
+		hb = self.glade.get_widget('vp_attach')
+		hb.add(self.view)
+
 		self.view.get_selection().set_mode('single')
 		self.view.connect('row_activated', self._sig_row_activated)
 
@@ -92,18 +93,7 @@ class win_attach(object):
 		self.reload()
 
 	def _sig_link(self, widget):
-		win = gtk.Dialog('Enter URL')
-		win.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL)
-		win.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
-		entry = gtk.Entry()
-		win.vbox.pack_start(entry)
-		win.show_all()
-
-		action = win.run()
-		filename = None
-		if action == gtk.RESPONSE_OK:
-			filename = entry.get_text()
-		win.destroy()
+		filename = common.file_selection(_('Select the destination file'))
 		
 		if not filename:
 			return
