@@ -87,6 +87,8 @@ def open_excel(fields, result):
 		common.message(_("Function only available for MS Office !\nSorry, OOo users :("))
 
 def datas_read(ids, model, fields, fields_view, prefix=''):
+	datas = rpc.session.rpc_exec_auth('/object', 'execute', model, 'export_data', ids, fields)
+	return datas
 	rfield = []
 	todo = {}
 	for f in fields:
@@ -126,7 +128,7 @@ def datas_read(ids, model, fields, fields_view, prefix=''):
 
 class win_export(object):
 	def __init__(self, model, ids, fields, preload = []):
-		self.glade = glade.XML(common.terp_path("terp.glade"),'win_save_as',gettext.textdomain())
+		self.glade = glade.XML(common.terp_path("terp.glade"), 'win_save_as', gettext.textdomain())
 		self.win = self.glade.get_widget('win_save_as')
 		self.ids = ids
 		self.model = model
@@ -157,21 +159,18 @@ class win_export(object):
 
 		self.fields = {}
 		def model_populate(fields, prefix_node='', prefix=None, prefix_value='', level=2):
-			def str_comp(x,y):
-				if x<y: return 1
-				elif x>y: return -1
-				else: return 0
 			fields_order = fields.keys()
-			fields_order.sort(lambda x,y: str_comp(fields[x].get('string', ''), fields[y].get('string', '')))
+			fields_order.sort(lambda x,y: -cmp(fields[x].get('string', ''), fields[y].get('string', '')))
 			for field in fields_order:
-				if fields[field]['type'] not in ('many2many','one2many'):
-					self.fields_data[prefix_node+field] = fields[field]
-					st_name = prefix_value+fields[field]['string'] or field 
-					node = self.model1.insert(prefix, 0, [st_name, prefix_node+field])
-					self.fields[prefix_node+field] = st_name
-					if fields[field].get('relation', None) and level>0:
-						fields2 = rpc.session.rpc_exec_auth('/object', 'execute', fields[field]['relation'], 'fields_get', False, rpc.session.context)
-						model_populate(fields2, prefix_node+field+'.', node, st_name+'.', level-1)
+				self.fields_data[prefix_node+field] = fields[field]
+				if prefix_node:
+					self.fields_data[prefix_node + field]['string'] = '%s%s' % (prefix_value, self.fields_data[prefix_node + field]['string'])
+				st_name = fields[field]['string'] or field 
+				node = self.model1.insert(prefix, 0, [st_name, prefix_node+field])
+				self.fields[prefix_node+field] = st_name
+				if fields[field].get('relation', False) and level>0:
+					fields2 = rpc.session.rpc_exec_auth('/object', 'execute', fields[field]['relation'], 'fields_get', False, rpc.session.context)
+					model_populate(fields2, prefix_node+field+'/', node, st_name+'/', level-1)
 		model_populate(fields)
 
 		self.view1.set_model(self.model1)
@@ -187,6 +186,19 @@ class win_export(object):
 		self.glade.signal_connect('on_but_select_all_clicked', self.sig_sel_all)
 		self.glade.signal_connect('on_but_select_clicked', self.sig_sel)
 		self.glade.signal_connect('on_but_unselect_clicked', self.sig_unsel)
+		self.glade.signal_connect('on_but_predefined_clicked', self.add_predef)
+
+		# Creating the predefined export view
+		self.pref_export = gtk.TreeView()
+		self.pref_export.append_column(gtk.TreeViewColumn('Export name', gtk.CellRendererText(), text=1))
+		self.pref_export.append_column(gtk.TreeViewColumn('Exported fields', gtk.CellRendererText(), text=2))
+		self.glade.get_widget('predefined_exports').add(self.pref_export)
+
+		self.pref_export.connect("row-activated", self.sel_predef)
+
+		# Fill the predefined export tree view and show everything
+		self.fill_predefwin()
+		self.pref_export.show_all()
 
 	def sig_sel_all(self, widget=None):
 		self.model2.clear()
@@ -202,14 +214,41 @@ class win_export(object):
 		self.model2.set(num, 0, store.get_value(iter,0), 1, store.get_value(iter,1))
 
 	def sig_unsel(self, widget=None):
-		def _sig_sel_del(store, path, iter):
-			store.remove(iter)
-		(store,paths) = self.view2.get_selection().get_selected_rows()
+		store, paths = self.view2.get_selection().get_selected_rows()
 		for p in paths:
 			store.remove(store.get_iter(p))
 
 	def sig_unsel_all(self, widget=None):
 		self.model2.clear()
+	
+	def fill_predefwin(self):
+		self.predef_model = gtk.ListStore(gobject.TYPE_PYOBJECT, gobject.TYPE_STRING, gobject.TYPE_STRING)
+		ir_export = rpc.RPCProxy('ir.exports')
+		ir_export_line = rpc.RPCProxy('ir.exports.line')
+		export_ids = ir_export.search([('resource', '=', self.model)])
+		for export in ir_export.read(export_ids):
+			fields = ir_export_line.read(export['export_fields'])
+			self.predef_model.append(([f['name'] for f in fields], export['name'], ', '.join([self.fields_data[f['name']]['string'] for f in fields])))
+		self.pref_export.set_model(self.predef_model)
+
+	def add_predef(self, button):
+		name = common.ask('What is the name of this export ?')
+		if not name:
+			return 
+		ir_export = rpc.RPCProxy('ir.exports')
+		iter = self.model2.get_iter_root()
+		fields = []
+		while iter:
+			field_name = self.model2.get_value(iter, 1)
+			fields.append(field_name)
+			iter = self.model2.iter_next(iter)
+		ir_export.create({'name' : name, 'resource' : self.model, 'export_fields' : [(0, 0, {'name' : f}) for f in fields]})
+		self.predef_model.append((fields, name, ','.join([self.fields_data[f]['string'] for f in fields])))
+	
+	def sel_predef(self, treeview, path, column):
+		self.model2.clear()
+		for field in self.predef_model[path[0]][0]:
+			self.model2.append((self.fields_data[field]['string'], field))
 
 	def go(self):
 		button = self.win.run()
@@ -223,20 +262,21 @@ class win_export(object):
 				iter = self.model2.iter_next(iter)
 			action = self.wid_action.get_active()
 			self.win.destroy()
-			datas = datas_read(self.ids, self.model, fields, self.fields_data)
-			result = []
-			for data in datas:
-				result.append([data.get(f, '') for f in fields])
+			result = datas_read(self.ids, self.model, fields, self.fields_data)
+			#result = []
+			#for data in datas:
+			#	result.append([data.get(f, '') for f in fields])
 
 			if not action:
 				open_excel(fields2, result)
 			else:
 				fname = common.file_selection(_('Export Data'))
 		 		if fname:
-					export_csv(fname, fields2, result, self.wid_write_field_names.get_active()
-)
+					export_csv(fname, fields2, result, self.wid_write_field_names.get_active())
 			return True
 		else:
 			self.win.destroy()
 			return False
 
+
+
