@@ -39,34 +39,24 @@ import csv, StringIO
 #
 # TODO: make it works with references
 #
-def import_csv(fname, f, model, fields):
+def import_csv(csv_data, f, model, fields):
+	fname = csv_data['fname']
 	content = file(fname,'rb').read()
 	input=StringIO.StringIO(content)
-	reader = csv.reader(input)
-	references = {}
-	dics = []
-	for row in reader:
-		dic={}
-		for i in range(len(f)):
-			if fields[f[i]]['type']=='integer':
-				dic[f[i]]=row[i] and int(row[i])
-			elif fields[f[i]]['type']=='float':
-				dic[f[i]]=row[i] and float(row[i])
-			elif fields[f[i]]['type']=='many2one':
-				dic[f[i]]=False
-				if row[i]:
-					res = rpc.session.rpc_exec_auth('/object', 'execute', fields[f[i]]['relation'], 'name_search', row[i], [])
-					if len(res):
-						dic[f[i]]=res[0][0]
-					else:
-						common.message(_('Import Error !\nField "%s" does not exist !') % (row[i],))
-						return False
-			else:
-				dic[f[i]]=str(row[i])
-		dics.append(dic)
-	for dic in dics:
-		rpc.session.rpc_exec_auth('/object', 'execute', model, 'create', dic)
-	common.message(_('Import Done'))
+	data = list(csv.reader(input, quotechar=csv_data['del'], delimiter=csv_data['sep']))[int(csv_data['skip']):]
+	datas = []
+	#if csv_data['combo']:
+	for line in data:
+		datas.append( map(lambda x:x.decode(csv_data['combo']).encode('utf8'), line))
+	res = rpc.session.rpc_exec_auth('/object', 'execute', model, 'import_data', f, datas)
+	if res[0]>=0:
+		common.message(_('Imported %d objects !\nYou will get a request for the complete result.') % (res[0],))
+	else:
+		d = ''
+		for key,val in res[1].items():
+			d+= ('\t%s: %s\n' % (str(key),str(val)))
+		error = u'Error trying to import this record:\n%s\nError Message:\n%s\n\n%s' % (d,res[2],res[3])
+		common.message_box('Importation Error !', unicode(error))
 	return True
 
 class win_import(object):
@@ -78,31 +68,50 @@ class win_import(object):
 
 		self.view1 = gtk.TreeView()
 		self.view1.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
-		self.glade.get_widget('imp_vp1').add(self.view1)
+		self.glade.get_widget('import_vp_left').add(self.view1)
 		self.view2 = gtk.TreeView()
 		self.view2.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
-		self.glade.get_widget('imp_vp2').add(self.view2)
+		self.glade.get_widget('import_vp_right').add(self.view2)
 		self.view1.set_headers_visible(False)
 		self.view2.set_headers_visible(False)
 
 		cell = gtk.CellRendererText()
-		column = gtk.TreeViewColumn(_('Field name'), cell, text=0)
+		column = gtk.TreeViewColumn(_('Field name'), cell, text=0, background=2)
 		self.view1.append_column(column)
 
 		cell = gtk.CellRendererText()
 		column = gtk.TreeViewColumn(_('Field name'), cell, text=0)
 		self.view2.append_column(column)
 
-		self.model1 = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
+		self.model1 = gtk.TreeStore(gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING)
 		self.model2 = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
 
 		for f in preload:
 			self.model2.set(self.model2.append(), 0, f[1], 1, f[0])
 
-		self.fields = fields
-		for f in fields:
-			if fields[f]['type'] not in ('one2many','many2many','reference'):
-				self.model1.set(self.model1.append(), 1, f, 0, fields[f].get('string', 'unknown'))
+		self.fields = {}
+		self.fields_invert = {}
+		def model_populate(fields, prefix_node='', prefix=None, prefix_value='', level=2):
+			def str_comp(x,y):
+				if x<y: return 1
+				elif x>y: return -1
+				else: return 0
+			fields_order = fields.keys()
+			fields_order.sort(lambda x,y: str_comp(fields[x].get('string', ''), fields[y].get('string', '')))
+			for field in fields_order:
+				if (fields[field]['type'] not in ('reference',)) and (not fields[field].get('readonly', False)):
+					self.fields_data[prefix_node+field] = fields[field]
+					st_name = prefix_value+fields[field]['string'] or field 
+					node = self.model1.insert(prefix, 0, [st_name, prefix_node+field, (fields[field].get('required', False) and '#ddddff') or 'white'])
+					self.fields[prefix_node+field] = st_name
+					self.fields_invert[st_name] = prefix_node+field
+					if fields[field]['type']=='one2many' and level>0:
+						fields2 = rpc.session.rpc_exec_auth('/object', 'execute', fields[field]['relation'], 'fields_get', False, rpc.session.context)
+						model_populate(fields2, prefix_node+field+'/', node, st_name+'/', level-1)
+		model_populate(fields)
+
+		#for f in fields:
+		#	self.model1.set(self.model1.append(), 1, f, 0, fields[f].get('string', 'unknown'))
 
 		self.view1.set_model(self.model1)
 		self.view2.set_model(self.model2)
@@ -113,6 +122,32 @@ class win_import(object):
 		self.glade.signal_connect('on_but_select_all_clicked', self.sig_sel_all)
 		self.glade.signal_connect('on_but_select_clicked', self.sig_sel)
 		self.glade.signal_connect('on_but_unselect_clicked', self.sig_unsel)
+		self.glade.signal_connect('on_but_autodetect_clicked', self.sig_autodetect)
+
+	def sig_autodetect(self, widget=None):
+		fname= self.glade.get_widget('import_csv_file').get_filename()
+		if not fname:
+			common.message('You must select an import file first !')
+			return True
+		csvsep= self.glade.get_widget('import_csv_sep').get_text()
+		csvdel= self.glade.get_widget('import_csv_del').get_text()
+
+		self.glade.get_widget('import_csv_skip').set_value(1)
+		try:
+			data = csv.reader(file(fname), quotechar=csvdel, delimiter=csvsep)
+		except:
+			common.warning('Error opening .CSV file', 'Input Error.')
+			return True
+		self.sig_unsel_all()
+		try:
+			for line in data:
+				for word in line:
+					num = self.model2.append()
+					self.model2.set(num, 0, word, 1, self.fields_invert[word])
+				break
+		except:
+			common.warning('Error processing your first line of the file.\nField %s is unknown !' % (word,), 'Import Error.')
+		return True
 
 	def sig_sel_all(self, widget=None):
 		self.model2.clear()
@@ -147,11 +182,17 @@ class win_import(object):
 				fields.append(self.model2.get_value(iter, 1))
 				fields2.append(self.model2.get_value(iter, 0))
 				iter = self.model2.iter_next(iter)
-			self.win.destroy()
 
-			fname = common.file_selection(_('Import CSV File'))
-			if fname:
-				return import_csv(fname, fields, self.model, self.fields)
+			csv = {
+				'fname': self.glade.get_widget('import_csv_file').get_filename(),
+				'sep': self.glade.get_widget('import_csv_sep').get_text(),
+				'del': self.glade.get_widget('import_csv_del').get_text(),
+				'skip': self.glade.get_widget('import_csv_skip').get_value(),
+				'combo': self.glade.get_widget('import_csv_combo').get_active_text()
+			}
+			self.win.destroy()
+			if csv['fname']:
+				return import_csv(csv, fields, self.model, self.fields)
 			return False
 		else:
 			self.win.destroy()
