@@ -61,8 +61,10 @@ class configmanager(object):
 			'login.login': 'demo',
 			'login.server': 'localhost',
 			'login.port': '8069',
+			'login.secure': False,
 			'client.modepda': False,
 			'client.toolbar': 'both',
+			'client.theme': 'none',
 			'path.share': os.path.dirname(__file__),
 			'path.pixmaps': os.path.dirname(__file__),
 			'tip.autostart': True,
