@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: rpc.py 2748 2006-04-14 13:14:58Z nicoe $
+# $Id: rpc.py 4044 2006-09-05 14:06:27Z ged $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -120,6 +120,13 @@ class rpc_session(object):
 		else:
 			raise rpc_exception(1, 'not logged')
 
+	def rpc_exec_auth_wo(self, obj, method, *args):
+		try:
+			sock = self._gw(self._url, self.uid, self._passwd, obj)
+			return sock.exec_auth(method, *args)
+		except:
+			raise rpc_exception(1, 'not logged')
+
 	def rpc_exec_auth(self, obj, method, *args):
 		if self._open:
 			try:
@@ -141,8 +148,12 @@ class rpc_session(object):
 		else:
 			raise rpc_exception(1, 'not logged')
 
-	def login(self, uname, passwd, url, port):
-		_url = 'http://' + url+':'+str(port)+'/xmlrpc'
+	def login(self, uname, passwd, url, port, secure):
+		if secure:
+			_protocol = "https://"
+		else:
+			_protocol = "http://"
+		_url = _protocol + url+':'+str(port)+'/xmlrpc'
 		_sock = xmlrpclib.ServerProxy(_url+'/common')
 		try:
 			res = _sock.login(uname, passwd)
@@ -163,12 +174,12 @@ class rpc_session(object):
 		return 1
 
 	def context_reload(self):
-		self.context={}
+		self.context = {}
 		# self.uid
 		context = self.rpc_exec_auth('/object', 'execute', 'ir.values', 'get', 'meta', False, [('res.users', self.uid or False)], False, {}, True, True, False)
 		for c in context:
 			if c[2]:
-				self.context[c[1]]=c[2]
+				self.context[c[1]] = c[2]
 
 	def logged(self):
 		return self._open
@@ -205,8 +216,3 @@ class RPCFunction(object):
 
 	def __call__(self, *args):
 		return session.rpc_exec_auth('/object', 'execute', self.object, self.func, *args)
-
-if __name__ == "__main__":
-	rpc = RPCProxy(3, 'admin')
-	print rpc.search('res.partner.address', [('email', 'in', ['fp@tiny.be'])])
-	print rpc.read('res.partner', [1])
