@@ -2,7 +2,7 @@
 
 ##############################################################################
 #
-# Copyright (c) 2004 TINY SPRL. (http://tiny.be) All Rights Reserved.
+# Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #                    Fabien Pinckaers <fp@tiny.Be>
 #
 # WARNING: This program as such is intended to be used by professional
@@ -37,7 +37,7 @@ GNU Public Licence.
 (c) 2003-TODAY, Fabien Pinckaers - Tiny sprl
 """
 __author__ = 'Fabien Pinckaers, <fp@tiny.be>'
-__version__ = "3.3.0"
+__version__ = "3.4.2"
 
 import __builtin__
 __builtin__.__dict__['tinyerp_version'] = __version__
@@ -115,8 +115,7 @@ if pixbuf:
 	icon_set = gtk.IconSet (pixbuf)
 	factory.add ('terp-translate', icon_set)
 
-# gtk.rc_parse("./terp-gtkrc")
-
+common.theme_set()
 
 try:
 	win = modules.gui.main.terp_main()
