@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: field.py 3097 2006-05-04 20:41:51Z pinky $
+# $Id: field.py 3935 2006-08-28 16:59:25Z pinky $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -35,6 +35,10 @@
 #
 from rpc import RPCProxy
 import rpc
+try:
+	from sets import Set as set
+except ImportError:
+	pass
 
 class ModelField(object):
 	def __new__(cls, type):
@@ -109,6 +113,11 @@ class CharField(object):
 	def get_default(self):
 		return self.get()
 
+class SelectionField(CharField):
+	def set(self, value, test_state=True, modified=False):
+		if value in [sel[0] for sel in self.attrs['selection']]:
+			super(SelectionField, self).set(value, test_state, modified)
+
 class FloatField(CharField):
 	def validate(self):
 		return True
@@ -160,9 +169,7 @@ class M2MField(CharField):
 		self.internal = []
 
 	def get(self):
-		if self.internal:
-			return [(6, 0, self.internal or [])]
-		return []
+		return [(6, 0, self.internal or [])]
 
 	def get_client(self):
 		return self.internal or []
@@ -173,7 +180,7 @@ class M2MField(CharField):
 	def set_client(self, value, test_state=False):
 		internal = self.internal
 		self.set(value, test_state, modified=False)
-		if internal != value:
+		if set(internal) != set(value):
 			self.modified = True
 			self.sig_changed()
 
@@ -222,8 +229,9 @@ class O2MField(CharField):
 	def set(self, value, test_state=False, modified=False):
 		from widget.model.group import ModelRecordGroup
 		self.internal = ModelRecordGroup(resource=self.attrs['relation'], fields={}, parent=self.parent)
-		self.internal.signal_connect(self.internal, 'model-changed', self._model_changed)
+		#self.internal.signal_connect(self.internal, 'model-changed', self._model_changed)
 		self.internal.pre_load(value, display=False)
+		#self.internal.signal_connect(self.internal, 'model-changed', self._model_changed)
 
 	def set_client(self, value, test_state=False):
 		self.set(value, test_state=test_state)
@@ -275,7 +283,10 @@ class ReferenceField(CharField):
 		model, id = value.split(',')
 		rpc2 = RPCProxy(model)
 		result = rpc2.name_get([id], rpc.session.context)
-		self.internal = model, result[0]
+		if result:
+			self.internal = model, result[0]
+		else:
+			self.internal = False
 
 TYPES = {
 	'char' : CharField,
@@ -285,6 +296,7 @@ TYPES = {
 	'many2many' : M2MField,
 	'one2many' : O2MField,
 	'reference' : ReferenceField,
+	'selection': SelectionField,
 }
 
 # vim:noexpandtab:
